@@ -1,5 +1,3 @@
-# -*- coding: utf-8 -*-
-
 #    Copyright (C) 2015 Yahoo! Inc. All Rights Reserved.
 #
 #    Licensed under the Apache License, Version 2.0 (the "License"); you may
@@ -37,6 +35,7 @@ driver_class_names = [
     "etcd.EtcdDriver",
     "file.FileDriver",
     "ipc.IPCDriver",
+    "kubernetes.SherlockDriver",
     "memcached.MemcachedDriver",
     "mysql.MySQLDriver",
     "pgsql.PostgresDriver",
@@ -74,9 +73,10 @@ print("")
 grouping_table = [
     [
         "Yes",  # Consul
-        "No",  # Etcd
+        "Yes",  # Etcd
         "Yes",  # File
         "No",  # IPC
+        "No",  # Kubernetes
         "Yes",  # Memcached
         "No",  # MySQL
         "No",  # PostgreSQL
@@ -109,6 +109,7 @@ leader_table = [
         "No",  # Etcd
         "No",  # File
         "No",  # IPC
+        "No",  # Kubernetes
         "Yes",  # Memcached
         "No",  # MySQL
         "No",  # PostgreSQL
@@ -138,6 +139,7 @@ lock_table = [
         "Yes",  # Etcd
         "Yes",  # File
         "Yes",  # IPC
+        "Yes",  # Kubernetes
         "Yes",  # Memcached
         "Yes",  # MySQL
         "Yes",  # PostgreSQL
