@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 #
 # Licensed under the Apache License, Version 2.0 (the "License"); you may
 # not use this file except in compliance with the License. You may obtain
@@ -17,7 +16,6 @@ import logging
 import threading
 
 import fasteners
-from oslo_utils import encodeutils
 from oslo_utils import timeutils
 import requests
 
@@ -39,18 +37,15 @@ def _translate_failures(func):
             return func(*args, **kwargs)
         except ValueError as e:
             # Typically json decoding failed for some reason.
-            utils.raise_with_cause(tooz.ToozError,
-                                   encodeutils.exception_to_unicode(e),
-                                   cause=e)
+            utils.raise_with_cause(tooz.ToozError, str(e), cause=e)
         except requests.exceptions.RequestException as e:
             utils.raise_with_cause(coordination.ToozConnectionError,
-                                   encodeutils.exception_to_unicode(e),
-                                   cause=e)
+                                   str(e), cause=e)
 
     return wrapper
 
 
-class _Client(object):
+class _Client:
     def __init__(self, host, port, protocol):
         self.host = host
         self.port = port
@@ -88,7 +83,7 @@ class EtcdLock(locking.Lock):
     _TOOZ_LOCK_PREFIX = "tooz_locks"
 
     def __init__(self, lock_url, name, coord, client, ttl=60):
-        super(EtcdLock, self).__init__(name)
+        super().__init__(name)
         self.client = client
         self.coord = coord
         self.ttl = ttl
@@ -242,7 +237,7 @@ class EtcdDriver(coordination.CoordinationDriver):
     )
 
     def __init__(self, member_id, parsed_url, options):
-        super(EtcdDriver, self).__init__(member_id, parsed_url, options)
+        super().__init__(member_id, parsed_url, options)
         host = parsed_url.hostname or self.DEFAULT_HOST
         port = parsed_url.port or self.DEFAULT_PORT
         options = utils.collapse(options)
@@ -257,8 +252,7 @@ class EtcdDriver(coordination.CoordinationDriver):
         try:
             self.client.self_stats()
         except requests.exceptions.ConnectionError as e:
-            raise coordination.ToozConnectionError(
-                encodeutils.exception_to_unicode(e))
+            raise coordination.ToozConnectionError(str(e))
 
     def get_lock(self, name):
         return EtcdLock(self.lock_encoder.check_and_encode(name), name,
