@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 #
 # Copyright © 2014 eNovance
 #
@@ -35,7 +34,7 @@ else:
 def ftok(name, project):
     # Similar to ftok & http://semanchuk.com/philip/sysv_ipc/#ftok_weakness
     # but hopefully without as many weaknesses...
-    h = hashlib.md5()
+    h = hashlib.md5(usedforsecurity=False)
     if not isinstance(project, bytes):
         project = project.encode('ascii')
     h.update(project)
@@ -57,7 +56,7 @@ class IPCLock(locking.Lock):
     _LOCK_PROJECT = b'__TOOZ_LOCK_'
 
     def __init__(self, name):
-        super(IPCLock, self).__init__(name)
+        super().__init__(name)
         self.key = ftok(name, self._LOCK_PROJECT)
         self._lock = None
 
@@ -70,7 +69,7 @@ class IPCLock(locking.Lock):
         else:
             return True
 
-    def acquire(self, blocking=True, shared=False):
+    def acquire(self, blocking=True, shared=False, timeout=None):
         if shared:
             raise tooz.NotImplemented
 
@@ -78,7 +77,10 @@ class IPCLock(locking.Lock):
                 sysv_ipc.SEMAPHORE_TIMEOUT_SUPPORTED is False):
             raise tooz.NotImplemented("This system does not support"
                                       " semaphore timeouts")
-        blocking, timeout = utils.convert_blocking(blocking)
+        if blocking is False and timeout is not None:
+            raise tooz.NotImplemented("Timeout without blocking is not "
+                                      "implemented")
+        blocking, timeout = utils.convert_blocking(blocking, timeout)
         start_time = None
         if not blocking:
             timeout = 0
@@ -169,7 +171,7 @@ class IPCDriver(coordination.CoordinationDriverWithExecutor):
     _INTERNAL_LOCK_NAME = "TOOZ_INTERNAL_LOCK"
 
     def _start(self):
-        super(IPCDriver, self)._start()
+        super()._start()
         self._group_list = sysv_ipc.SharedMemory(
             ftok(self._GROUP_LIST_KEY, self._GROUP_PROJECT),
             sysv_ipc.IPC_CREAT,
@@ -177,7 +179,7 @@ class IPCDriver(coordination.CoordinationDriverWithExecutor):
         self._lock = self.get_lock(self._INTERNAL_LOCK_NAME)
 
     def _stop(self):
-        super(IPCDriver, self)._stop()
+        super()._stop()
         try:
             self._group_list.detach()
             self._group_list.remove()
@@ -226,12 +228,12 @@ class IPCDriver(coordination.CoordinationDriverWithExecutor):
     def watch_join_group(self, group_id, callback):
         # Check the group exist
         self.get_members(group_id).get()
-        super(IPCDriver, self).watch_join_group(group_id, callback)
+        super().watch_join_group(group_id, callback)
 
     def watch_leave_group(self, group_id, callback):
         # Check the group exist
         self.get_members(group_id).get()
-        super(IPCDriver, self).watch_leave_group(group_id, callback)
+        super().watch_leave_group(group_id, callback)
 
     def _get_groups_handler(self):
         with self._lock:
