@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 #
 # Copyright © 2014 eNovance
 #
@@ -19,8 +18,9 @@ import errno
 import functools
 import logging
 import socket
+import ssl
 
-from oslo_utils import encodeutils
+from oslo_utils import strutils
 from pymemcache import client as pymemcache_client
 
 import tooz
@@ -43,23 +43,19 @@ def _failure_translator():
         yield
     except pymemcache_client.MemcacheUnexpectedCloseError as e:
         utils.raise_with_cause(coordination.ToozConnectionError,
-                               encodeutils.exception_to_unicode(e),
-                               cause=e)
-    except (socket.timeout, socket.error,
-            socket.gaierror, socket.herror) as e:
+                               str(e), cause=e)
+    except (socket.timeout, OSError, socket.gaierror, socket.herror) as e:
         # TODO(harlowja): get upstream pymemcache to produce a better
         # exception for these, using socket (vs. a memcache specific
         # error) seems sorta not right and/or the best approach...
-        msg = encodeutils.exception_to_unicode(e)
+        msg = str(e)
         if e.errno is not None:
-            msg += " (with errno %s [%s])" % (errno.errorcode[e.errno],
-                                              e.errno)
+            msg += " (with errno {} [{}])".format(errno.errorcode[e.errno],
+                                                  e.errno)
         utils.raise_with_cause(coordination.ToozConnectionError,
                                msg, cause=e)
     except pymemcache_client.MemcacheError as e:
-        utils.raise_with_cause(tooz.ToozError,
-                               encodeutils.exception_to_unicode(e),
-                               cause=e)
+        utils.raise_with_cause(tooz.ToozError, str(e), cause=e)
 
 
 def _translate_failures(func):
@@ -76,7 +72,7 @@ class MemcachedLock(locking.Lock):
     _LOCK_PREFIX = b'__TOOZ_LOCK_'
 
     def __init__(self, coord, name, timeout):
-        super(MemcachedLock, self).__init__(self._LOCK_PREFIX + name)
+        super().__init__(self._LOCK_PREFIX + name)
         self.coord = coord
         self.timeout = timeout
 
@@ -211,6 +207,13 @@ class MemcachedDriver(coordination.CoordinationDriverCachedRunWatchers,
     lock_timeout        30
     leader_timeout      30
     max_pool_size       None
+    use_ssl             False
+    ca_cert             None
+    ssl_key             None
+    ssl_key_password    None
+    ssl_cert            None
+    ssl_ciphers         None
+    ssl_check_hostname  False
     ==================  =======
 
     General recommendations/usage considerations:
@@ -252,7 +255,7 @@ class MemcachedDriver(coordination.CoordinationDriverCachedRunWatchers,
     STILL_ALIVE = b"It's alive!"
 
     def __init__(self, member_id, parsed_url, options):
-        super(MemcachedDriver, self).__init__(member_id, parsed_url, options)
+        super().__init__(member_id, parsed_url, options)
         self.host = (parsed_url.hostname or "localhost",
                      parsed_url.port or 11211)
         default_timeout = self._options.get('timeout', self.DEFAULT_TIMEOUT)
@@ -269,6 +272,29 @@ class MemcachedDriver(coordination.CoordinationDriverCachedRunWatchers,
         else:
             self.max_pool_size = None
         self._acquired_locks = []
+        self.ssl_context = None
+        use_ssl = self._options.get('use_ssl', 'False')
+        use_ssl = strutils.bool_from_string(use_ssl,
+                                            strict=False,
+                                            default=False)
+        if use_ssl:
+            ca_cert = self._options.get('ca_cert')
+            ssl_key = self._options.get('ssl_key')
+            ssl_cert = self._options.get('ssl_cert')
+            ssl_key_password = self._options.get('ssl_key_password')
+            ciphers = self._options.get('ssl_ciphers')
+            check_hostname = self._options.get('ssl_check_hostname', 'False')
+            check_hostname = strutils.bool_from_string(check_hostname,
+                                                       strict=False,
+                                                       default=False)
+            self.ssl_context = ssl.create_default_context(
+                               ssl.Purpose.SERVER_AUTH, cafile=ca_cert)
+            if ciphers is not None:
+                self.ssl_context.set_ciphers(ciphers)
+            self.ssl_context.check_hostname = check_hostname
+            self.ssl_context.load_cert_chain(certfile=ssl_cert,
+                                             keyfile=ssl_key,
+                                             password=ssl_key_password)
 
     @staticmethod
     def _msgpack_serializer(key, value):
@@ -287,21 +313,22 @@ class MemcachedDriver(coordination.CoordinationDriverCachedRunWatchers,
 
     @_translate_failures
     def _start(self):
-        super(MemcachedDriver, self)._start()
+        super()._start()
         self.client = pymemcache_client.PooledClient(
             self.host,
             serializer=self._msgpack_serializer,
             deserializer=self._msgpack_deserializer,
             timeout=self.timeout,
             connect_timeout=self.timeout,
-            max_pool_size=self.max_pool_size)
+            max_pool_size=self.max_pool_size,
+            tls_context=self.ssl_context)
         # Run heartbeat here because pymemcache use a lazy connection
         # method and only connect once you do an operation.
         self.heartbeat()
 
     @_translate_failures
     def _stop(self):
-        super(MemcachedDriver, self)._stop()
+        super()._stop()
         for lock in list(self._acquired_locks):
             lock.release()
         self.client.delete(self._encode_member_id(self._member_id))
@@ -529,7 +556,7 @@ class MemcachedDriver(coordination.CoordinationDriverCachedRunWatchers,
                     self._member_id))
 
     def run_watchers(self, timeout=None):
-        result = super(MemcachedDriver, self).run_watchers(timeout=timeout)
+        result = super().run_watchers(timeout=timeout)
         self.run_elect_coordinator()
         return result
 
