@@ -1,5 +1,3 @@
-# -*- coding: utf-8 -*-
-
 #    Copyright (C) 2014 Yahoo! Inc. All Rights Reserved.
 #
 #    Licensed under the Apache License, Version 2.0 (the "License"); you may
@@ -14,14 +12,14 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-from distutils import version
 import functools
 import logging
 import string
 import threading
 
-from oslo_utils import encodeutils
+from oslo_utils import netutils
 from oslo_utils import strutils
+from oslo_utils import versionutils
 import redis
 from redis import exceptions
 from redis import sentinel
@@ -59,27 +57,22 @@ def _handle_failures(n_tries=15):
                             "retry limit has been reached, aborting - %s", e
                         )
                         utils.raise_with_cause(
-                            coordination.ToozConnectionError,
-                            encodeutils.exception_to_unicode(e),
-                            cause=e)
+                            coordination.ToozConnectionError, str(e), cause=e)
                     LOG.debug("Redis connection error, will retry - %s", e)
 
                 except (exceptions.TimeoutError) as e:
                     utils.raise_with_cause(coordination.ToozConnectionError,
-                                           encodeutils.exception_to_unicode(e),
-                                           cause=e)
+                                           str(e), cause=e)
                 except exceptions.RedisError as e:
-                    utils.raise_with_cause(tooz.ToozError,
-                                           encodeutils.exception_to_unicode(e),
-                                           cause=e)
+                    utils.raise_with_cause(tooz.ToozError, str(e), cause=e)
         return wrapper
     return inner
 
 
 class RedisLock(locking.Lock):
     def __init__(self, coord, client, name, timeout):
-        name = "%s_%s_lock" % (coord.namespace, str(name))
-        super(RedisLock, self).__init__(name)
+        name = "{}_{}_lock".format(coord.namespace, str(name))
+        super().__init__(name)
         # NOTE(jd) Make sure we don't release and heartbeat at the same time by
         # using a exclusive access lock (LP#1557593)
         self._exclusive_access = threading.Lock()
@@ -102,10 +95,10 @@ class RedisLock(locking.Lock):
         return bool(self._client.delete(self.name))
 
     @_handle_failures()
-    def acquire(self, blocking=True, shared=False):
+    def acquire(self, blocking=True, shared=False, timeout=None):
         if shared:
             raise tooz.NotImplemented
-        blocking, timeout = utils.convert_blocking(blocking)
+        blocking, timeout = utils.convert_blocking(blocking, timeout)
         acquired = self._lock.acquire(
             blocking=blocking, blocking_timeout=timeout)
         if acquired:
@@ -159,7 +152,8 @@ class RedisDriver(coordination.CoordinationDriverCachedRunWatchers,
 
     The Redis driver connection URI should look like::
 
-      redis://[:PASSWORD@]HOST:PORT[?OPTION=VALUE[&OPTION2=VALUE2[&...]]]
+      redis://[USERNAME:PASSWORD@]HOST:PORT
+          [?OPTION=VALUE[&OPTION2=VALUE2[&...]]]
 
     For a list of options recognized by this driver, see the documentation
     for the member CLIENT_ARGS, and to determine the expected types of those
@@ -217,7 +211,7 @@ class RedisDriver(coordination.CoordinationDriverCachedRunWatchers,
     enum member(s) that can be used to interogate how this driver works.
     """
 
-    MIN_VERSION = version.LooseVersion("2.6.0")
+    MIN_VERSION = "2.6.0"
     """
     The min redis version that this driver requires to operate with...
     """
@@ -257,11 +251,17 @@ class RedisDriver(coordination.CoordinationDriverCachedRunWatchers,
         'retry_on_timeout',
         'socket_keepalive',
         'socket_timeout',
+        'socket_connect_timeout',
+        'health_check_interval',
         'ssl',
         'ssl_certfile',
         'ssl_keyfile',
+        'ssl_ca_certs',
         'sentinel',
         'sentinel_fallback',
+        'sentinel_username',
+        'sentinel_password',
+        'sentinel_ssl',
     ])
     """
     Keys that we allow to proxy from the coordinator configuration into the
@@ -281,14 +281,21 @@ class RedisDriver(coordination.CoordinationDriverCachedRunWatchers,
     #: Client arguments that are expected to be boolean convertible.
     CLIENT_BOOL_ARGS = frozenset([
         'retry_on_timeout',
+        'socket_keepalive',
         'ssl',
+        'sentinel_ssl',
     ])
 
     #: Client arguments that are expected to be int convertible.
     CLIENT_INT_ARGS = frozenset([
         'db',
-        'socket_keepalive',
+    ])
+
+    #: Client arguments that are expected to be float convertible.
+    CLIENT_FLOAT_ARGS = frozenset([
         'socket_timeout',
+        'socket_connect_timeout',
+        'health_check_interval',
     ])
 
     #: Default socket timeout to use when none is provided.
@@ -358,7 +365,7 @@ return 1
     EXCLUDE_OPTIONS = CLIENT_LIST_ARGS
 
     def __init__(self, member_id, parsed_url, options):
-        super(RedisDriver, self).__init__(member_id, parsed_url, options)
+        super().__init__(member_id, parsed_url, options)
         self._parsed_url = parsed_url
         self._encoding = self._options.get('encoding', self.DEFAULT_ENCODING)
         timeout = self._options.get('timeout', self.CLIENT_DEFAULT_SOCKET_TO)
@@ -378,23 +385,16 @@ return 1
         self._server_info = {}
         self._scripts = {}
 
-    def _check_fetch_redis_version(self, geq_version, not_existent=True):
-        if isinstance(geq_version, str):
-            desired_version = version.LooseVersion(geq_version)
-        elif isinstance(geq_version, version.LooseVersion):
-            desired_version = geq_version
-        else:
-            raise TypeError("Version check expects a string/version type")
+    def _check_fetch_redis_version(self, desired_version, not_existent=True):
         try:
-            redis_version = version.LooseVersion(
-                self._server_info['redis_version'])
+            redis_version = self._server_info['redis_version']
         except KeyError:
             return (not_existent, None)
-        else:
-            if redis_version < desired_version:
-                return (False, redis_version)
-            else:
-                return (True, redis_version)
+
+        if versionutils.is_compatible(desired_version, redis_version,
+                                      same_major=False):
+            return (True, redis_version)
+        return (False, redis_version)
 
     @property
     def namespace(self):
@@ -410,6 +410,13 @@ return 1
     _dumps = staticmethod(utils.dumps)
     _loads = staticmethod(utils.loads)
 
+    @classmethod
+    def _parse_sentinel(cls, sentinel):
+        host, port = netutils.parse_host_port(sentinel)
+        if host is None or port is None:
+            raise ValueError('Malformed sentinel server format')
+        return (host, port)
+
     @classmethod
     def _make_client(cls, parsed_url, options, default_socket_timeout):
         kwargs = {}
@@ -421,6 +428,8 @@ return 1
             if not parsed_url.path:
                 raise ValueError("Expected socket path in parsed urls path")
             kwargs['unix_socket_path'] = parsed_url.path
+        if parsed_url.username:
+            kwargs['username'] = parsed_url.username
         if parsed_url.password:
             kwargs['password'] = parsed_url.password
         for a in cls.CLIENT_ARGS:
@@ -432,6 +441,8 @@ return 1
                 v = options[a]
             elif a in cls.CLIENT_INT_ARGS:
                 v = int(options[a])
+            elif a in cls.CLIENT_FLOAT_ARGS:
+                v = float(options[a])
             else:
                 v = options[a]
             kwargs[a] = v
@@ -442,33 +453,44 @@ return 1
         # sentinel arg.
         if 'sentinel' in kwargs:
             sentinel_hosts = [
-                tuple(fallback.split(':'))
-                for fallback in kwargs.get('sentinel_fallback', [])
+                cls._parse_sentinel(fallback)
+                for fallback in kwargs.pop('sentinel_fallback', [])
             ]
-            sentinel_hosts.insert(0, (kwargs['host'], kwargs['port']))
+            sentinel_hosts.insert(0, (kwargs.pop('host'), kwargs.pop('port')))
+            sentinel_name = kwargs.pop('sentinel')
+            sentinel_kwargs = {}
+            # NOTE(tkajinam): Copy socket_* options, according to the logic
+            # in redis-py
+            for key in kwargs:
+                if key.startswith('socket_'):
+                    sentinel_kwargs[key] = kwargs[key]
+            if kwargs.pop('sentinel_ssl', False):
+                sentinel_kwargs['ssl'] = True
+                for key in ('ssl_certfile', 'ssl_keyfile', 'ssl_ca_certs'):
+                    if key in kwargs:
+                        sentinel_kwargs[key] = kwargs[key]
+            for key in ('username', 'password'):
+                if 'sentinel_' + key in kwargs:
+                    sentinel_kwargs[key] = kwargs.pop('sentinel_' + key)
             sentinel_server = sentinel.Sentinel(
                 sentinel_hosts,
-                socket_timeout=kwargs['socket_timeout'])
-            sentinel_name = kwargs['sentinel']
-            del kwargs['sentinel']
-            if 'sentinel_fallback' in kwargs:
-                del kwargs['sentinel_fallback']
-            master_client = sentinel_server.master_for(sentinel_name, **kwargs)
-            # The master_client is a redis.StrictRedis using a
+                sentinel_kwargs=sentinel_kwargs,
+                **kwargs)
+            master_client = sentinel_server.master_for(sentinel_name)
+            # The master_client is a redis.Redis using a
             # Sentinel managed connection pool.
             return master_client
-        return redis.StrictRedis(**kwargs)
+        return redis.Redis(**kwargs)
 
     @_handle_failures()
     def _start(self):
-        super(RedisDriver, self)._start()
+        super()._start()
         try:
             self._client = self._make_client(self._parsed_url, self._options,
                                              self.timeout)
         except exceptions.RedisError as e:
             utils.raise_with_cause(coordination.ToozConnectionError,
-                                   encodeutils.exception_to_unicode(e),
-                                   cause=e)
+                                   str(e), cause=e)
         else:
             # Ensure that the server is alive and not dead, this does not
             # ensure the server will always be alive, but does insure that it
@@ -555,7 +577,7 @@ return 1
                 lock.release()
             except tooz.ToozError:
                 LOG.warning("Unable to release lock '%s'", lock, exc_info=True)
-        super(RedisDriver, self)._stop()
+        super()._stop()
         if self._client is not None:
             # Make sure we no longer exist...
             beat_id = self._encode_beat_id(self._member_id)
@@ -672,8 +694,8 @@ return 1
                                             for m in gone_members)
                 p.hdel(encoded_group, *encoded_gone_members)
                 p.execute()
-                return set(m for m in potential_members
-                           if m not in gone_members)
+                return {m for m in potential_members
+                        if m not in gone_members}
             return potential_members
 
         return RedisFutureResult(self._submit(self._client.transaction,
@@ -774,7 +796,7 @@ return 1
                                                      self._member_id))
 
     def run_watchers(self, timeout=None):
-        result = super(RedisDriver, self).run_watchers(timeout=timeout)
+        result = super().run_watchers(timeout=timeout)
         self.run_elect_coordinator()
         return result
 
