@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 #
 #    Copyright © 2013-2015 eNovance Inc. All Rights Reserved.
 #
@@ -16,6 +15,7 @@
 
 import threading
 import time
+import unittest
 from unittest import mock
 import urllib
 
@@ -304,15 +304,16 @@ class TestAPI(tests.TestWithCoordinator):
 
     def test_heartbeat(self):
         if not self._coord.requires_beating:
-            raise testcase.TestSkipped("Test not applicable (heartbeating"
-                                       " not required)")
+            raise unittest.SkipTest(
+                "Test not applicable (heartbeating not required)"
+            )
         self._coord.heartbeat()
 
     def test_heartbeat_loop(self):
         if not self._coord.requires_beating:
-            raise testcase.TestSkipped("Test not applicable (heartbeating"
-                                       " not required)")
-
+            raise unittest.SkipTest(
+                "Test not applicable (heartbeating not required)"
+            )
         heart = self._coord.heart
         self.assertFalse(heart.is_alive())
         heart.start()
@@ -818,22 +819,10 @@ class TestAPI(tests.TestWithCoordinator):
             self.assertTrue(f.result())
 
     def test_get_lock_concurrency_locking_two_lock_process(self):
-        # NOTE(jd) Using gRPC and forking is not supported so this test might
-        # very likely hang forever or crash. See
-        # https://github.com/grpc/grpc/issues/10140#issuecomment-297548714 for
-        # more info.
-        if self.url.startswith("etcd3://"):
-            self.skipTest("Unable to use etcd3 with fork()")
         self._do_test_get_lock_concurrency_locking_two_lock(
             futures.ProcessPoolExecutor, False)
 
     def test_get_lock_serial_locking_two_lock_process(self):
-        # NOTE(jd) Using gRPC and forking is not supported so this test might
-        # very likely hang forever or crash. See
-        # https://github.com/grpc/grpc/issues/10140#issuecomment-297548714 for
-        # more info.
-        if self.url.startswith("etcd3://"):
-            self.skipTest("Unable to use etcd3 with fork()")
         self._do_test_get_lock_serial_locking_two_lock(
             futures.ProcessPoolExecutor, False)
 
@@ -923,8 +912,8 @@ class TestAPI(tests.TestWithCoordinator):
         name = tests.get_random_uuid()
         blocking_value = 10.12
         lock = self._coord.get_lock(name)
-        with mock.patch.object(lock, 'acquire', wraps=True, autospec=True) as \
-                mock_acquire:
+        with mock.patch.object(lock, 'acquire', wraps=lock.acquire,
+                               autospec=True) as mock_acquire:
             with lock(blocking_value):
                 mock_acquire.assert_called_once_with(blocking_value)
 
@@ -998,7 +987,7 @@ class TestAPI(tests.TestWithCoordinator):
 
 class TestHook(testcase.TestCase):
     def setUp(self):
-        super(TestHook, self).setUp()
+        super().setUp()
         self.hooks = tooz.coordination.Hooks()
         self.triggered = False
 
